/*globals Components */

var CustomURIHandler = {
  debug: false,
  
  init: function() {
    this.log("CustomURIHandler.Registering _URIContentListener as parentContentListener") ;
    Components.classes["@mozilla.org/uriloader;1"]
              .getService(Components.interfaces.nsIURILoader)
              .registerContentListener(this);
    var wnd = window.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
                    .getInterface(Components.interfaces.nsIWebNavigation)
                    .QueryInterface(Components.interfaces.nsIDocShell)
                    .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
                    .getInterface(Components.interfaces.nsIURIContentListener) ;
    wnd.parentContentListener = this ;
  },

  log: function(msg) {
    if (this.debug) {
      Components.classes['@mozilla.org/consoleservice;1']
                .getService(Components.interfaces.nsIConsoleService)
                .logStringMessage(msg);
    }
  },

  QueryInterface: function(iid) {
    if (iid.equals(Components.interfaces.nsISupports)
        || iid.equals(Components.interfaces.nsISupportsWeakReference)
        || iid.equals(Components.interfaces.nsIURIContentListener)) {
        return this ;
    }
    throw Components.results.NS_ERROR_NO_INTERFACE ;
  },

  isPreferred: function(contentType, isContentPreferred, desiredContentType) {
    this.log("CustomURIHandler.isPreferred") ;
    this.log(contentType) ;
    return true ;
  },
    
  onStartURIOpen: function(URI) {
    this.log("CustomURIHandler.onStartURIOpen: " + URI.spec) ;
    if (URI.scheme != "file") return false;

    var path = URI.spec.substr(8).replace(/\//g, "\\") ;
    var extension = path.match(/([^\.]+)$/)[0] ;
    if (extension.match("\\\\$") == "\\") extension = "\\" ; // Is a folder

    switch (extension) {
      case "html":
        return false ;
      case "exe": // Launch Windows executables
      case "msi": // Launch Windows installers
      case "pdf": // Open PDF documents in their default viewer
      case "oxt": // Install OpenOffice.org extension
      case "\\":  // Open folder in Windows Explorer
        try {
          return this.executePath(path) ;
        } catch (e) {
          alert("Couldn't execute: " + path ) ;
        }
        return true ;
      case "xpi": // Handle extension files off to Firefox and Thunderbird
        try {
          if (path.indexOf("thunderbird") != -1)
            return this.revealPath(path) ;
          else
            return this.handleXpiPath(path) 
        } catch (e) {
          alert("Couldn't install extension: " + path ) ;
        }
        return true ;
      default: // Unknown files, open their containing directory
        try {
          return this.revealPath(path) ;
        } catch (e) {
          alert("Couldn't show folder of: " + path ) ;
        }
        return true ;
    }
  },
  
  executePath: function(path) {
    this.log("CustomURIHandler.executePath: " + path) ;
    var file = Components.classes["@mozilla.org/file/local;1"]
                         .createInstance(Components.interfaces.nsILocalFile) ;
    file.initWithPath(path) ;
    file.launch() ;
    return true ;
  },

  revealPath: function(path) {
    this.log("CustomURIHandler.revealPath: " + path) ;
    var file = Components.classes["@mozilla.org/file/local;1"]
                         .createInstance(Components.interfaces.nsILocalFile) ;
    file.initWithPath(path) ;
    file.reveal() ;
    return true ;
  },

  handleXpiPath: function(path) {
    this.log("CustomURIHandler.handleXpiPath: " + path) ;
    var wrk = Components.classes["@mozilla.org/windows-registry-key;1"]
                        .createInstance(Components.interfaces.nsIWindowsRegKey) ;
    if (path.indexOf("thunderbird") != -1)
      wrk.open(wrk.ROOT_KEY_LOCAL_MACHINE,
               "Software\\Microsoft\\Windows\\CurrentVersion\\App Paths\\thunderbird.exe",
               wrk.ACCESS_READ) ;
    else
      wrk.open(wrk.ROOT_KEY_LOCAL_MACHINE,
               "Software\\Microsoft\\Windows\\CurrentVersion\\App Paths\\firefox.exe",
               wrk.ACCESS_READ) ;
    var exefile = Components.classes["@mozilla.org/file/local;1"]
                            .createInstance(Components.interfaces.nsILocalFile) ;
    var exe = wrk.readStringValue("") ;
    wrk.close() ;
    exefile.initWithPath(exe) ;
    // create an nsIProcess
    var process = Components.classes["@mozilla.org/process/util;1"]
                            .createInstance(Components.interfaces.nsIProcess) ;
    process.init(exefile) ;
    var args = [path] ;
    process.run(false, args, args.length) ;
  }
} ;

window.addEventListener("load", function(e) {
  window.document.title =
    window.document.getElementById("valo-cd").contentWindow.document.title;
  CustomURIHandler.init();
}, false) ;