/****** BEGIN LICENSE BLOCK *****
 - Version: MPL 1.1/GPL 2.0/LGPL 2.1
 -
 - The contents of this file are subject to the Mozilla Public License Version
 - 1.1 (the "License"); you may not use this file except in compliance with
 - the License. You may obtain a copy of the License at
 - http://www.mozilla.org/MPL/
 -
 - Software distributed under the License is distributed on an "AS IS" basis,
 - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 - for the specific language governing rights and limitations under the
 - License.
 -
 - The Original Code is mozilla.org code.
 -
 - Alternatively, the contents of this file may be used under the terms of
 - either the GNU General Public License Version 2 or later (the "GPL"), or
 - the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 - in which case the provisions of the GPL or the LGPL are applicable instead
 - of those above. If you wish to allow use of your version of this file only
 - under the terms of either the GPL or the LGPL, and not to allow others to
 - use your version of this file under the terms of the MPL, indicate your
 - decision by deleting the provisions above and replace them with the notice
 - and other provisions required by the GPL or the LGPL. If you do not delete
 - the provisions above, a recipient may use your version of this file under
 - the terms of any one of the MPL, the GPL or the LGPL.
 -
 - ***** END LICENSE BLOCK *****/

// origin: browser.jar:content/browser/browser.js

/**
 * Content area tooltip.
 * XXX - this must move into XBL binding/equiv! Do not want to pollute
 *       browser.js with functionality that can be encapsulated into
 *       browser widget. TEMPORARY!
 *
 * NOTE: Any changes to this routine need to be mirrored in ChromeListener::FindTitleText()
 *       (located in mozilla/embedding/browser/webBrowser/nsDocShellTreeOwner.cpp)
 *       which performs the same function, but for embedded clients that
 *       don't use a XUL/JS layer. It is important that the logic of
 *       these two routines be kept more or less in sync.
 *       (pinkerton)
 **/
function FillInHTMLTooltip(tipElement)
{
  var retVal = false;
  if (tipElement.namespaceURI == "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul")
    return retVal;

  const XLinkNS = "http://www.w3.org/1999/xlink";


  var titleText = null;
  var XLinkTitleText = null;
  var direction = tipElement.ownerDocument.dir;

  while (!titleText && !XLinkTitleText && tipElement) {
    if (tipElement.nodeType == Node.ELEMENT_NODE) {
      titleText = tipElement.getAttribute("title");
      XLinkTitleText = tipElement.getAttributeNS(XLinkNS, "title");
      var defView = tipElement.ownerDocument.defaultView;
      // XXX Work around bug 350679:
      // "Tooltips can be fired in documents with no view".
      if (!defView)
        return retVal;
      direction = defView.getComputedStyle(tipElement, "")
        .getPropertyValue("direction");
    }
    tipElement = tipElement.parentNode;
  }

  var tipNode = document.getElementById("aHTMLTooltip");
  tipNode.style.direction = direction;
  
  [titleText, XLinkTitleText].forEach(function (t) {
    if (t && (/\S/).test(t)) {

      // Per HTML 4.01 6.2 (CDATA section), literal CRs and tabs should be
      // replaced with spaces, and LFs should be removed entirely.
      // XXX Bug 322270: We don't preserve the result of entities like &#13;,
      // which should result in a line break in the tooltip, because we can't
      // distinguish that from a literal character in the source by this point.
      t = t.replace(/[\r\t]/g, ' ');
      t = t.replace(/\n/g, '');

      tipNode.setAttribute("label", t);
      retVal = true;
    }
  });

  return retVal;
}