#!/bin/sh
# Examples:
# ./build-cd.sh valo-cd-v9-en-draft html-ui/valo-cd-v9-en-draft
# ./build-cd.sh valo-cd-v9-fi-vedos html-ui/valo-cd-v9-fi-vedos
# ./build-cd.sh <target dir> <ui source dir>

# abort on errors
set -e

# print commands before execution
set -x

cd_target_dir=$1
html_ui_build_dir=$2
lang=`cat $html_ui_build_dir/VALO-CD/content/language.info`
name=`cat $html_ui_build_dir/VALO-CD/content/name.info`
version=`cat $html_ui_build_dir/VALO-CD/content/version.info`

# check that the arguments are in correct order
if [ -e "$html_ui_build_dir/start.exe" -o ! -e "$html_ui_build_dir/VALO-CD/content/index.html" ]; then
    echo >&2 "\"$html_ui_build_dir\": doesn't look like a html-ui build result"
    exit 10
fi

# start build from a clean state
mkdir -p "$cd_target_dir"

# copy template
cp -a cd-template-$lang/* "$cd_target_dir/"

# copy common stuff to target
cp -a VALO-CD autorun.* start.* public-keys "$cd_target_dir/"

sed -i s/VALO-CD/VALO-CD-v$version/ $cd_target_dir/autorun.inf

cp -a "$html_ui_build_dir"/* "$cd_target_dir/"

# Note! This link breaks when new versions are released:
# wget -nv -nc http://releases.mozilla.org/pub/mozilla.org/xulrunner/releases/1.9.2.19/runtimes/xulrunner-1.9.2.19.en-US.win32.zip
unzip -q xulrunner-1.9.2.19.en-US.win32.zip -d "$cd_target_dir/VALO-CD/"

# checksums
(cd "$cd_target_dir" && find . -type f -print0 | xargs -0 md5sum) > md5sums
(cd "$cd_target_dir" && find . -type f -print0 | xargs -0 sha1sum) > sha1sums

mv md5sums sha1sums "$cd_target_dir/"

# package the results
(cd "$cd_target_dir" && zip -q -r ../`basename "$cd_target_dir"`.zip .)
md5sum `basename "$cd_target_dir"`.zip > `basename "$cd_target_dir"`.zip.md5
sha1sum `basename "$cd_target_dir"`.zip > `basename "$cd_target_dir"`.zip.sha1

genisoimage -J -R -l -o `basename "$cd_target_dir"`.iso -V "$name v$version" -v -iso-level 4 "$cd_target_dir"

md5sum `basename "$cd_target_dir"`.iso > `basename "$cd_target_dir"`.iso.md5
sha1sum `basename "$cd_target_dir"`.iso > `basename "$cd_target_dir"`.iso.sha1
