#!/bin/bash
# Examples:
# ./build-ui.sh http://www.valo-cd.net/wiki/Version_9_EN valo-cd-v9-en-draft/VALO-CD/content ../../programs ../../guides
# ./build-ui.sh http://www.valo-cd.fi/wiki/Versio_9 valo-cd-v9-fi-vedos/VALO-CD/content ../../ohjelmat ../../oppaat
# ./build-ui.sh <index url> <target directory> <relative paths to programs and guides from target dir>

# Note!
# If you see error:
#   WARNING {{Collection|title-full=...}} is missing. Falling back to the default
# .. then adjust manually the title in index.html

# abort on errors
set -e

# print commands before execution
set -x

url=$1
root=$2
programs=$3
guides=$4

if [ -z "$SASS" ]; then
    if which sass >/dev/null; then
        SASS=sass
    elif [ -e "sass/bin/sass" ]; then
        SASS="sass/bin/sass"
    else
        echo >&2 "Need \$SASS or sass or sass/bin/sass"
        echo >&2 "See http://sass-lang.com/ or git clone git://github.com/nex3/sass.git"
        exit 10
    fi
fi

# start build
mkdir -p "$root"

cp -a fonts images js "$root/"

# valo-cd.xml builds index.html, resources.txt, css/categories.scss, 
# and css/logo.scss
xsltproc --load-trace --novalid --stringparam url "$url" --stringparam programs "$programs" --stringparam guides "$guides" valo-cd.xsl valo-cd.html > "$root/index.html"

"$SASS" css/valo-cd.scss valo-cd.css
cp -a valo-cd.css "$root/"

# download linked resources
egrep "\.(png|jpg|gif)$" resources.txt|sort -u|wget -nv -nc -nH --cut-dirs=4 -x -i - -P "$root/images" || true
egrep "\.(exe|msi)$" resources.txt|sort -u|wget -nv -nc -nH --cut-dirs=2 -x -i - -P "$root/$programs" || true
egrep "\.pdf$" resources.txt|sort -u|wget -nv -nc -nH --cut-dirs=2 -x -i - -P "$root/$guides" || true
egrep "\.(lngx|xml|oxt|xpi)$" resources.txt|sort -u|wget -nv -nc -nH --cut-dirs=1 -x -i - -P "$root/$programs" || true

lang=`cat language.info`
mv *.info $root

# images contains the default VALO-CD.net logo,
# but replace it if there is a localized version
if [ -e "localized_logos/logo_$lang.png" ]; then
    cp "localized_logos/logo_$lang.png" "$root/images/logo.png"
fi

# sanity checks
if find "$root/images" "$root/$programs" "$root/$guides" -type f|xargs file|grep HTML >&2; then
    echo >&2 "Error: Wget downloaded unwanted HTML files"
    exit 10
fi

ls >/dev/null `egrep "\\\.(png|jpg|gif)$" resources.txt | sort -u | sed -e "s#.*/\([^/]*\)\\\$#$root/images/\1#"`
ls >/dev/null `egrep "\\\.(exe|msi)$" resources.txt | sort -u | sed -e "s#.*/\([^/]*\)\\\$#$root/$programs/\1#"`
ls >/dev/null `egrep "\\\.pdf$" resources.txt | sort -u | sed -e "s#.*/\([^/]*\)\\\$#$root/$guides/\1#"`
ls >/dev/null `egrep "\\\.(lngx|xml|oxt|xpi)$" resources.txt | sort -u | sed -e "s#.*/\([^/]*/[^/]*\)\\\$#$root/$programs/\1#"`

echo >&2 "Build successful."
