/*
 valo-cd.js
 Copyright (C) 2010  Asko Soukka <asko.soukka@iki.fi>

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/*globals Hyphenator*/
var VALO = {
  /* Enables debugging messages via console.log() */
  debug: false,

  /* Stores VALO-CD browsing history */
  history: [],

  /* Toggles vertical category scroller and fires animated scrolls */
  scroller: {
    hide: function() {
      $("html").css("overflow-y", "hidden");
    },
    show: function() {
      $("html").css("overflow-y", "auto");
    },
    get_top: function() {
      return Math.max($("html").scrollTop(), $("body").scrollTop());
    },
    set_top: function(top, duration) {
      if (top !== this.get_top()) {
        if (duration === undefined) {
          $("html,body").stop(true, false).animate({ scrollTop: top });
        } else {
          $("html,body").stop(true, false).animate({ scrollTop: top }, duration);
        }
      }
    }
  },

  /* Scrolls to the given category (relies on titles to be closed) */
  select_category: function(id, duration) {
    if (this.debug) console.log(["select_category", id].join(': '));

    var category = $("#" + id + ".category"),
        title = category.children("h2"),
        scroll_top = this.scroller.get_top(),
        title_middle = title.offset().top + title.height() / 2 - scroll_top,
        scroll_to;

    if (category.height() > title_middle * 1.25) {
      scroll_to = category.offset().top;
    } else {
      scroll_to = category.offset().top + category.height() / 2 - title_middle;
    }

    if (duration === undefined) {
      this.scroller.set_top(scroll_to);
    } else {
      this.scroller.set_top(scroll_to, duration);
    }
  },

  /* Opens the given title (or looks it up from the history) */
  open_title: function(id) {
    if (this.debug) console.log(["open_title", id].join(': '));

    var breadcrumbs = $('<ul class="breadcrumbs"></ul>'),
        idx, that = this, close_title = function(title) {
          return function(e) { that.close_title(title); return false; };
        };

    // Look the title up from the browsing history
    for (idx in that.history) {
      if (this.history.hasOwnProperty(idx)) {
        if (this.history[idx].title === id) {
          if (Number(idx) === this.history.length - 1) {
            return false;
          } else {
            return this.close_title(this.history[Number(idx) + 1].title);
          }
        }
      }
    }

    // Push the title to the browsing history
    this.history.push({
      top: this.scroller.get_top(),
      title: id
    });

    // Hide category scroller
    this.scroller.hide();

    // Look up the title element and toggle it opened
    $("#"+id+".icon")
      .unbind()
      .removeClass("icon")
      .addClass("title")
      .css("z-index", this.history.length);

    // Build breadcrumbs from the browsing history
    for (idx in that.history) {
      if (this.history.hasOwnProperty(idx)) {
        $("<li>" + (idx === '0' ?
          $("#" + this.history[idx].title).parent(".category").children("h2").text() :
          $("#" + this.history[Number(idx) - 1].title).children("h3").text()) +"</li>")
          .bind("click", close_title(idx === '0' ? undefined : this.history[idx].title))
          .addClass(idx === '0' ?
            $("#"+this.history[idx].title).parent(".category").attr("id") :
            $("#"+this.history[Number(idx) - 1].title).parent(".category").attr("id"))
          .appendTo(breadcrumbs);
        if (Number(idx) === this.history.length - 1) {
          $("<li>" + $("#" + this.history[idx].title).children("h3").text() +"</li>")
            .addClass($("#"+this.history[idx].title).parent(".category").attr("id"))
            .appendTo(breadcrumbs);
        }
      }
    }

    // Append breadcrumbs after the title heading
    $("#"+id+".title").children("h3").before(breadcrumbs);
  },

  /* Closes titles in the browsing history until also the given title is closed */
  close_title: function(id) {
    if (this.debug) console.log(["close_title", id !== undefined ? id : "all"].join(': '));

    var history, that = this, open_title = function(e) {
      that.open_title(this.id); return false;
    };

    while (this.history.length > 0) {
      history = this.history.pop();
      $("#" + history.title + ".title")
        .removeClass("title")
        .addClass("icon")
        .css("z-index", null)
        .bind("click", open_title)
        .children(".breadcrumbs").remove();
      if (this.history.length === 0) {
        this.scroller.show();
        this.scroller.set_top(history.top, 0);
      }
      if (id !== undefined && history.title === id) {
        break;
      }
    }
  }
};

$(document).ready(function(){
  // Bind logo to work like "home" button
  $("h1, h1 + p").bind("click", function(e) {
    var id = $(".category:eq(0)").attr("id");
    VALO.close_title(); // close all
    VALO.select_category(id);
    return false;
  });

  // Bind category headings to scroll to their contents
  $(".category h2")
    .bind("click", function(e) {
      var id = $(this).parent(".category").attr("id");
      VALO.close_title(); // close all
      VALO.select_category(id);
      return false;
  });

  // Transform titles to icons and bind them to open themselves
  $(".title")
    .removeClass("title")
    .addClass("icon")
    .bind("click", function(e) {
      VALO.open_title(this.id);
      return false;
    });

  // Disable event propagation when download buttons are clicked
  $('.download')
    .bind("click", function (e) { e.stopPropagation(); return true; } );

  // Enable magic linking between titles (via #title-id-anchors)
  $('a[href^="#"]')
    .each(function(idx) {
      if ($(this.hash + ".icon, " + this.hash + ".title").length > 0) {
        $(this).bind("click", function(e) {
          if ($(this).parents(".icon, .title").length > 0
            && $(this).parents(".icon, .title").attr("id") === this.hash.substring(1)) {
            $(this.hash).animate({scrollTop: 0 });
          } else {
            VALO.select_category($(this.hash).parents(".category").attr("id"), 0);
            VALO.open_title(this.hash.substring(1));
          }
          $(this).addClass("visited");
          return false;
        });
      } else if ($(this.hash).parent(".icon, .title").length > 0) {
        $(this).bind("click", function(e) {
          VALO.select_category($(this.hash).parents(".category").attr("id"), 0);
          VALO.open_title($(this.hash).parent(".icon, .title").attr("id"));
          $(this).addClass("visited");
          return true;
        });
      } else if ($(this.hash + ".category").length > 0) {
        $(this).bind("click", function(e) {
          VALO.close_title(); // close all
          VALO.select_category(this.hash.substring(1));
          return false;
        });
      }
    });

  // Transform lists of screenshots to hoverable carousels
  $(".screenshots").each(function(idx) {
    var gallery = $(this),
        screenshots = gallery.children("li");
    if (screenshots.length > 1) {
      gallery.before('<div class="selector" />');
      $(this).children("li")
        .css("display", "none")
        .css("cursor", "pointer")
        .each(function(idx) {
          var that = this;
          $('<span class="radio" />')
            .appendTo(gallery.prev(".selector"))
            .css("width", (1 / screenshots.length) * (100 - 0.4 * screenshots.length) + "%")
            .bind("mouseenter", function(e) {
              $(this)
                .addClass("selected")
                .siblings(".radio").removeClass("selected");
              $(that)
                .css("display", "list-item")
                .siblings("li").css("display", "none");
            });
          $(this).bind("click", function(e) {
            gallery.toggleClass("zoomed");
            gallery.prev(".selector").toggleClass("zoomed");
          });
          $(this).bind("mousemove", function(e) {
            var left = $(this).offset().left,
                width = $(this).width(), x = e.pageX;
            var selection = parseInt(((x - left) / width) * screenshots.length, 10);
            gallery.prev(".selector")
              .children(".radio:eq(" + selection + ")")
                .not(".selected").addClass("selected").end()
              .siblings(".radio.selected").removeClass("selected");
            $(this).parent("ul")
              .children("li:eq(" + selection +")")
                .not(":visible").css("display", "list-item").end()
              .siblings(":visible").css("display", "none");
          });
        }).first().css("display", "list-item");
      gallery.prev(".selector").children(".radio").first().addClass("selected");
    }
  });

  // Enable keyboard navigation (well... bind backspace to previous title)
  $(window).keypress( function(e) {
    if (e.keyCode == "8") {
      if (VALO.history.length === 0)  {
        VALO.scroller.set_top(0);
      } else if ($("#" + VALO.history[VALO.history.length - 1].title).scrollTop() > 0) {
        $("#" + VALO.history[VALO.history.length - 1].title).animate({scrollTop: 0 });
      } else {
        VALO.close_title(VALO.history[VALO.history.length - 1].title);
      }
      e.preventDefault();
      return false;
    } else {
      return true;
    }
  });

  // Open the title given in the location hash
  if (window.location.hash.length > 0) {
    if ($(window.location.hash + ".icon").length > 0) {
      VALO.select_category($(window.location.hash).parent(".category").attr("id"), 0);
      VALO.open_title(window.location.hash.substring(1));
    } else if ($(window.location.hash).parent(".icon").length > 0) {
      VALO.select_category($(window.location.hash).parents(".category").attr("id"), 0);
      VALO.open_title($(window.location.hash).parent(".icon").attr("id"));
    }
  }

  // Fire up hyphenator
  $("p, ul, ol, dl, blockquote").addClass("hyphenate");
  Hyphenator.run();
});