<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp "&#160;"> ]>
<xsl:stylesheet version="1.0"
  xmlns="http://www.w3.org/1999/xhtml"
  xmlns:xhtml="http://www.w3.org/1999/xhtml"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:str="http://exslt.org/strings"
  extension-element-prefixes="exsl str"
  exclude-result-prefixes="xhtml xsl">

<!--
  Global variables:

  $data 
    url to wiki page containing table of contents for the release

  $programs
    path to executables
    
  $guides
    path to pdfs
-->

<!-- Load given index url -->
<xsl:variable name="data" select="document($url)//xhtml:div[@id='bodyContent']"/>

<!-- Initialize "base" url and "api" variables -->
<xsl:variable name="base" select="str:replace($url, str:tokenize($url, '/')[last()], '')"/>
<xsl:variable name="meta"
  select="concat($base, 'api.php?action=query&amp;prop=info&amp;inprop=url&amp;format=xml&amp;titles=')"/>

<!-- Get lang from wiki when available -->
<xsl:variable name="language">
 <xsl:choose>
  <xsl:when test="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='language']//xhtml:td">
    <xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='language']//xhtml:td)"/>
  </xsl:when>
  <xsl:otherwise>en</xsl:otherwise>
 </xsl:choose>
</xsl:variable>

<xsl:variable name="lcletters">abcdefghijklmnopqrstuvwxyz</xsl:variable>
<xsl:variable name="ucletters">ABCDEFGHIJKLMNOPQRSTUVWXYZ</xsl:variable>
<xsl:variable name="language-caps" select="translate($language,$lcletters,$ucletters)"/>

<!-- Replace xml:lang -->
<xsl:template match="@xml:lang">
  <xsl:attribute name="xml:lang">
    <xsl:value-of select="$language"/>
  </xsl:attribute>
</xsl:template>


<!-- Replace Hyphenator spelling hints when available -->
<xsl:template match="xhtml:script[contains(., 'Hyphenator.addExceptions')]">
  <xsl:copy>
    <xsl:apply-templates select="@*"/>
    <xsl:choose>
      <xsl:when test="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='spellings']//xhtml:td">
        <xsl:text>Hyphenator.addExceptions('</xsl:text>
        <xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='language']//xhtml:td)"/>
        <xsl:text>', "</xsl:text>
        <xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='spellings']//xhtml:td)"/>
        <xsl:text>");</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="node()"/>
        <xsl:message terminate="no">
          <xsl:text>WARNING {{Collection|missing=...}} is missing. Falling back to the default: </xsl:text>
          <xsl:value-of select="."/>
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:copy>
</xsl:template>

<!-- Replace title from wiki when available -->
<xsl:template match="xhtml:title">
  <xsl:copy>
    <xsl:choose>
      <xsl:when test="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='title-full']//xhtml:td">
        <xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='title-full']//xhtml:td)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="@*|node()"/>
        <xsl:message terminate="no">
          <xsl:text>WARNING {{Collection|title-full=...}} is missing. Falling back to the default: "</xsl:text>
          <xsl:value-of select="."/>
          <xsl:text>".</xsl:text>
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:copy>
</xsl:template>

<!-- Replace title from wiki when available -->
<xsl:template match="xhtml:h1">
  <xsl:copy>
    <xsl:choose>
      <xsl:when test="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='title']//xhtml:td">
        <xsl:apply-templates select="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='title']//xhtml:td/node()"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="@*|node()"/>
        <xsl:message terminate="no">
          <xsl:text>WARNING {{Collection|title=...}} is missing. Falling back to the default: "</xsl:text>
          <xsl:value-of select="."/>
          <xsl:text>".</xsl:text>
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:copy>
</xsl:template>

<!-- Replace slogan from wiki when available -->
<xsl:template match="xhtml:p[preceding-sibling::xhtml:*[1][name()='h1']]">
  <xsl:copy>
    <xsl:choose>
      <xsl:when test="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='slogan']//xhtml:td">
        <xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='slogan']//xhtml:td)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="@*|node()"/>
        <xsl:message terminate="no">
          <xsl:text>WARNING {{Collection|slogan=...}} is missing. Falling back to the default: "</xsl:text>
          <xsl:value-of select="."/>
          <xsl:text>".</xsl:text>
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:copy>
</xsl:template>

<!-- Append everything to template body -->
<xsl:template match="xhtml:body">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()"/>
    <xsl:for-each select="$data//xhtml:h2[child::xhtml:span[@class='mw-headline']]">
      <xsl:call-template name="category">
        <xsl:with-param name="category-id" select="xhtml:span[@class='mw-headline']/@id"/>
        <xsl:with-param name="category-name" select="xhtml:span[@class='mw-headline']"/>
        <xsl:with-param name="category-titles" select="following-sibling::xhtml:ul[1]/xhtml:li"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:copy>
  <exsl:document href="css/categories.scss" method="text">
    <xsl:choose>
      <xsl:when test="$data//xhtml:table[@class='metadata' and contains(@style, 'background-color:')]">
        <xsl:variable name="style" select="$data//xhtml:table[@class='metadata']/@style"/>
        <xsl:text>$background-color: </xsl:text>
        <xsl:value-of select="normalize-space(str:split(str:split($style, 'background-color:')[last()], ';')[1])"/>
        <xsl:text>;&#10;</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:message terminate="no">
          <xsl:text>INFO Use {{Collection|background=...}} to customize the background color.</xsl:text>
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:for-each select="$data//xhtml:h2[child::xhtml:span[@class='mw-headline']]">
      <xsl:choose>
        <xsl:when test="@style">
          <xsl:text>@include category("</xsl:text>
          <xsl:call-template name="canonical-id">
            <xsl:with-param name="id" select="xhtml:span[@class='mw-headline']/@id"/>
          </xsl:call-template>
          <xsl:text>", </xsl:text>
          <xsl:value-of select="normalize-space(str:split(str:split(@style, 'background:')[last()], ';')[1])"/>
          <xsl:text>);&#10;</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:message terminate="yes">
            <xsl:text>FATAL {{Section|name=</xsl:text>
            <xsl:call-template name="canonical-id">
              <xsl:with-param name="id" select="xhtml:span[@class='mw-headline']/@id"/>
            </xsl:call-template>
            <xsl:text>|color=...}} is missing at </xsl:text>
            <xsl:value-of select="$url"/>
            <xsl:text>.</xsl:text>
          </xsl:message>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </exsl:document>
  <exsl:document href="resources.txt" method="text">
    <xsl:if test="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='icon']//xhtml:img">
      <xsl:variable name="src" select="$data//xhtml:table[@class='metadata']//xhtml:tr[@id='icon']//xhtml:img/@src"/>
      <xsl:value-of select="concat($base, str:replace($src, concat('/', str:split($src, '/')[1], '/'), ''))"/>
      <xsl:text>&#10;</xsl:text>
    </xsl:if>
    <xsl:for-each select="$data//xhtml:h2[child::xhtml:span[@class='mw-headline']]">
      <xsl:variable name="category-titles" select="following-sibling::xhtml:ul[1]/xhtml:li"/>
      <xsl:for-each select="$category-titles">
        <xsl:call-template name="title-resourcelist">
          <xsl:with-param name="title-id" select="str:split(document(concat($meta, str:encode-uri(xhtml:a/@title, true())))//page/@fullurl, '/')[last()]"/>
        </xsl:call-template>
      </xsl:for-each>
    </xsl:for-each>
  </exsl:document>
  <!-- save language code in file -->
  <exsl:document href="language.info" method="text"><xsl:value-of select="$language-caps"/></exsl:document>
  <!-- save project name -->
  <exsl:document href="name.info" method="text"><xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='title']//xhtml:td)"/></exsl:document>
  <!-- save project version -->
  <exsl:document href="version.info" method="text"><xsl:value-of select="normalize-space($data//xhtml:table[@class='metadata']//xhtml:tr[@id='version']//xhtml:td)"/></exsl:document>
</xsl:template>

<!-- Generate category -->
<xsl:template name="category">
  <xsl:param name="category-id"/>
  <xsl:param name="category-name"/>
  <xsl:param name="category-titles"/>
  <div class="category">
    <xsl:attribute name="id">
      <xsl:call-template name="canonical-id">
        <xsl:with-param name="id" select="$category-id"/>
      </xsl:call-template>
    </xsl:attribute>
    <h2><xsl:value-of select="$category-name"/></h2>
    <div class="label"><xsl:value-of select="$category-name"/></div> 
    <xsl:for-each select="$category-titles">
      <xsl:call-template name="title">
        <xsl:with-param name="title-id" select="str:split(document(concat($meta, str:encode-uri(xhtml:a/@title, true())))//page/@fullurl, '/')[last()]"/>
      </xsl:call-template>
    </xsl:for-each>
  </div>
</xsl:template>

<!-- Generate Title -->
<xsl:template name="title">
  <xsl:param name="title-id"/>
  <xsl:variable name="title" select="document(concat($base, $title-id))"/>
  <xsl:variable name="title-name" select="str:replace($title//xhtml:h1, concat(' ', $language-caps), '')"/>
  <xsl:variable name="title-icon" select="$title//xhtml:tr[@id='icon']//xhtml:img/@src"/>
  <xsl:variable name="title-desc" select="$title//xhtml:tr[@id='icon']//xhtml:a/@title"/>
  <xsl:variable name="title-download" select="$title//xhtml:tr[@id='download']//xhtml:a/@href"/>
  <xsl:variable name="download-label" select="$title//xhtml:tr[@id='download']//xhtml:a/text()"/>
  <xsl:variable name="link-label" select="$title//xhtml:tr[@id='homepage']/xhtml:th/text()"/>
  <xsl:variable name="title-link" select="$title//xhtml:tr[@id='homepage']//xhtml:a/@href"/>
  <xsl:variable name="version-label" select="$title//xhtml:tr[@id='version']/xhtml:th/text()"/>
  <xsl:variable name="title-version" select="$title//xhtml:tr[@id='version']/xhtml:td/text()"/>
  <xsl:variable name="title-screens" select="$title//xhtml:td[@class='screenshot']"/>
  <div>
    <xsl:attribute name="id">
      <xsl:call-template name="canonical-id">
        <xsl:with-param name="id" select="$title-id"/>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:attribute name="class">
      <xsl:choose>
        <xsl:when test="$title-icon">        
          <xsl:text>title</xsl:text>
        </xsl:when>
        <xsl:when test="$title//xhtml:div[@id='bodyContent']/xhtml:table[@class='metadata']">
          <xsl:text>title guide</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>title guide info</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <h3><xsl:value-of select="$title-name"/></h3>
    <xsl:if test="$title-icon">
      <img class="icon" alt="">
        <xsl:attribute name="src">
          <xsl:value-of select="concat('images/', str:split($title-icon, '/')[last()])"/>
        </xsl:attribute>
        <xsl:attribute name="title">
          <xsl:value-of select="$title-desc"/>
        </xsl:attribute>
      </img>
    </xsl:if>
    <xsl:if test="$title-download">
      <a class="download">
        <xsl:attribute name="href">
          <xsl:choose>
            <xsl:when test="str:split($title-download, '.')[last()]='pdf'">
              <xsl:value-of select="concat($guides, '/', str:split($title-download, '/')[last()])"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="concat($programs, '/', str:split($title-download, '/')[last()])"/>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
        <xsl:value-of select="$download-label"/>
      </a>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="$title//xhtml:div[@id='bodyContent']/xhtml:table[@class='metadata']">
        <xsl:apply-templates 
          select="$title//xhtml:div[@id='bodyContent']/*[preceding-sibling::xhtml:table[@class='metadata'] and following-sibling::xhtml:div[@class='printfooter']][1]"/>
        <xsl:if test="$title-screens">
          <ul class="screenshots">
            <xsl:for-each select="$title-screens//xhtml:div[@class='thumbinner']">
              <li>
                <img alt="">
                  <xsl:attribute name="src">
                    <xsl:variable name="src" select=".//xhtml:img[@class='thumbimage']/@src"/>
                    <xsl:value-of select="concat('images/', str:split($src, '/')[last() - 1])"/>
                  </xsl:attribute>
                  <xsl:attribute name="title">
                    <xsl:value-of select=".//xhtml:div[@class='thumbcaption']/text()"/>
                  </xsl:attribute>
                </img>
              </li>
            </xsl:for-each>
          </ul>
        </xsl:if>
        <xsl:apply-templates 
          select="$title//xhtml:div[@id='bodyContent']/*[preceding-sibling::xhtml:table[@class='metadata'] and following-sibling::xhtml:div[@class='printfooter']][position()>1]"/>
        <xsl:if test="$title-version">
          <dl class="metadata">
            <dt><xsl:value-of select="$version-label"/></dt>
            <dd><xsl:value-of select="$title-version"/></dd>
            <dt><xsl:value-of select="$link-label"/></dt>
            <dd><a>
              <xsl:attribute name="title">
                <xsl:value-of select="concat($link-label, ' ', $title-link)"/>
              </xsl:attribute>
              <xsl:attribute name="href">
                <xsl:value-of select="$title-link"/>
              </xsl:attribute>
              <xsl:value-of select="$title-link"/>
            </a></dd>
          </dl>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates
          select="$title//xhtml:div[@id='bodyContent']/*[preceding-sibling::xhtml:div[@id='jump-to-nav'] and following-sibling::xhtml:div[@class='printfooter']]"/>
      </xsl:otherwise>
    </xsl:choose>
  </div>
</xsl:template>

<!-- Drop inline javascripts -->
<xsl:template match="xhtml:body//xhtml:script"/>

<!-- Drop dummy anchors -->
<xsl:template match="xhtml:a[not(@href)]"/>

<!-- Drop <br/>s -->
<xsl:template match="xhtml:br"/>

<!-- Transform <i/>s to <em/>s -->
<xsl:template match="xhtml:i">
  <em>
    <xsl:apply-templates select="@*|node()"/>
  </em>
</xsl:template>

<!-- Transform <b/>s to <strong/>s -->
<xsl:template match="xhtml:b">
  <strong>
    <xsl:apply-templates select="@*|node()"/>
  </strong>
</xsl:template>

<!-- Simplify TOC -->
<xsl:template match="xhtml:table[@id='toc']">
  <xsl:apply-templates select=".//xhtml:div[@id='toctitle']"/>
  <xsl:apply-templates select=".//xhtml:ul"/>
</xsl:template>
<xsl:template match="xhtml:div[@id='toctitle']">
  <p>
    <xsl:value-of select="."/>
    <xsl:text>:</xsl:text>
  </p>
</xsl:template>
<xsl:template match="xhtml:li[contains(concat(' ', normalize-space(@class), ' '), ' toclevel')]">
  <xsl:copy>
    <xsl:apply-templates select="node()"/>
  </xsl:copy>
</xsl:template>
<xsl:template match="xhtml:span[contains(concat(' ', normalize-space(@class), ' '), ' tocnumber ')]"/>
<xsl:template match="xhtml:span[contains(concat(' ', normalize-space(@class), ' '), ' toctext ')]">
  <xsl:apply-templates select="node()"/>
</xsl:template>

<!-- Transform <h2/>s to <h4/>s -->
<xsl:template match="xhtml:h2[child::xhtml:span[@class='mw-headline']]">
  <h4>
    <xsl:attribute name="id">
      <xsl:call-template name="canonical-id">
        <xsl:with-param name="id" select="xhtml:span[@class='mw-headline']/@id"/>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:apply-templates select="@*|node()"/>
  </h4>
</xsl:template>

<!-- Transform inline images -->
<xsl:template match="xhtml:div[contains(concat(' ', normalize-space(@class), ' '), ' thumb ')]">
  <img>
    <xsl:apply-templates select=".//xhtml:img[@class='thumbimage']/@*"/>
    <xsl:attribute name="src">
      <xsl:variable name="src" select=".//xhtml:img[@class='thumbimage']/@src"/>
      <xsl:value-of select="concat('images/', str:split($src, '/')[last() - 1])"/>
    </xsl:attribute>
    <xsl:attribute name="class">
      <xsl:text>inline</xsl:text>
    </xsl:attribute>
  </img>
</xsl:template>

<!-- Transform inline (non MediaWiki thumb) images -->
<xsl:template match="xhtml:div[@class='floatleft' and contains(., xhtml:img)]">
  <img>
    <xsl:apply-templates select=".//xhtml:img/@*"/>
    <xsl:attribute name="src">
      <xsl:variable name="src" select=".//xhtml:img/@src"/>
      <xsl:value-of select="concat('images/', str:split($src, '/')[last()])"/>
    </xsl:attribute>
    <xsl:attribute name="class">
      <xsl:text>logo</xsl:text>
    </xsl:attribute>
  </img>
</xsl:template>

<!-- Add titles to absolute links -->
<xsl:template match="xhtml:a[starts-with(@href, 'http')]">
  <xsl:copy>
    <xsl:apply-templates select="@href"/>
    <xsl:attribute name="title">
      <xsl:value-of select="@href"/>
    </xsl:attribute>
    <xsl:apply-templates select="node()"/>
  </xsl:copy>
</xsl:template>

<!-- Transform generic inline resource links -->
<xsl:template match="xhtml:a[starts-with(@href, 'http') and contains('exe pdf', str:split(@href, '.')[last()])]">
  <xsl:copy>
    <xsl:attribute name="href">
      <xsl:choose>
        <xsl:when test="str:split(@href, '.')[last()]='pdf'">
          <xsl:value-of select="concat($guides, '/', str:split(@href, '/')[last()])"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="concat($programs, '/', str:split(@href, '/')[last()])"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:attribute name="title">
      <xsl:value-of select="str:split(@href, '/')[last()]"/>
    </xsl:attribute>
    <xsl:apply-templates select="node()"/>
  </xsl:copy>
</xsl:template>

<!-- Transform program spesific inline resource links -->
<xsl:template match="xhtml:a[starts-with(@href, 'http') and contains('lngx xml oxt xpi', str:split(@href, '.')[last()])]">
  <xsl:copy>
    <xsl:attribute name="href">
      <xsl:value-of select="concat($programs, '/', str:split(@href, '/')[last()-1], '/', str:split(@href, '/')[last()])"/>
    </xsl:attribute>
    <xsl:attribute name="title">
      <xsl:value-of select="str:split(@href, '/')[last()]"/>
    </xsl:attribute>
    <xsl:apply-templates select="node()"/>
  </xsl:copy>
</xsl:template>

<!-- Add title to anchors -->
<xsl:template match="xhtml:a[starts-with(@href, '#') and not(@title)]">
  <xsl:copy>
    <xsl:apply-templates select="@*"/>
    <xsl:attribute name="title">
      <xsl:value-of select="translate(@href, '._#', '- ')"/>
    </xsl:attribute>
    <xsl:attribute name="href">
      <xsl:call-template name="canonical-id">
        <xsl:with-param name="id" select="@href"/>
      </xsl:call-template>
    </xsl:attribute>
    <xsl:apply-templates select="node()"/>
  </xsl:copy>
</xsl:template>

<!-- Transform relative links -->
<xsl:template match="xhtml:a[@title and not(starts-with(@href, '#') or starts-with(@href, 'http'))]">
  <xsl:variable name="metadata" select="document(concat($meta, str:encode-uri(@title, true())))"/>
  <xsl:choose>
    <!-- Remove "new" (red) MediaWiki links -->
    <xsl:when test="@class='new'">
      <xsl:value-of select="text()"/>
    </xsl:when>
    <!-- Transform links between titles -->
    <xsl:when test="$metadata//page/@fullurl">
      <xsl:copy>
        <xsl:apply-templates select="@*"/>
        <xsl:attribute name="href">
          <xsl:text>#</xsl:text>
          <xsl:call-template name="canonical-id">
            <xsl:with-param name="id" select="str:split($metadata//page/@fullurl, '/')[last()]"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:apply-templates select="node()"/>
      </xsl:copy>
    </xsl:when>
    <!-- Do nothing -->
    <xsl:otherwise>
      <xsl:apply-templates select="@*|node()"/>
      <xsl:attribute name="href">
        <xsl:call-template name="canonical-id">
          <xsl:with-param name="id" select="@href"/>
        </xsl:call-template>
      </xsl:attribute>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<!-- Canonize HTML IDs (remove dots etc...) -->
<xsl:template name="canonical-id">
  <xsl:param name="id"/>
  <xsl:value-of select="str:decode-uri(translate($id, '_.:', '--'))"/>
</xsl:template>

<!-- Remove MediaWiki editsections -->
<xsl:template match="xhtml:span[@class='editsection']"/>

<!-- Normalize space within headings -->
<xsl:template match="xhtml:span[@class='mw-headline']">
  <xsl:value-of select="normalize-space(text())"/>
</xsl:template>

<!-- Generate Title resourcelist-->
<xsl:template name="title-resourcelist">
  <xsl:param name="title-id"/>
  <xsl:variable name="title" select="document(concat($base, $title-id))"/>
  <xsl:variable name="title-icon" select="$title//xhtml:tr[@id='icon']//xhtml:img/@src"/>
  <xsl:variable name="title-download" select="$title//xhtml:tr[@id='download']//xhtml:a/@href"/>
  <xsl:variable name="title-screens" select="$title//xhtml:td[@class='screenshot']"/>
  <xsl:if test="$title-icon">
    <xsl:value-of select="concat($base, str:replace($title-icon, concat('/', str:split($title-icon, '/')[1], '/'), ''))"/>
    <xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="$title-download">
    <xsl:value-of select="$title-download"/>
    <xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="$title-screens">
    <xsl:for-each select="$title-screens//xhtml:div[@class='thumbinner']">
      <xsl:variable name="src" select=".//xhtml:img[@class='thumbimage']/@src"/>
      <xsl:variable name="stripped" select="str:replace($src, concat('/', str:split($src, '/')[1], '/'), '')"/>
      <xsl:value-of select="concat($base, str:replace(str:replace($stripped, 'thumb/', ''), concat('/', str:split($stripped, '/')[last()]), ''))"/>
      <xsl:text>&#10;</xsl:text>
    </xsl:for-each>
  </xsl:if>
  <xsl:for-each select="$title//xhtml:div[@id='bodyContent']/xhtml:div[contains(concat(' ', normalize-space(@class), ' '), ' thumb ')]">
    <xsl:variable name="src" select=".//xhtml:img[@class='thumbimage']/@src"/>
    <xsl:variable name="stripped" select="str:replace($src, concat('/', str:split($src, '/')[1], '/'), '')"/>
    <xsl:value-of select="concat($base, str:replace(str:replace($stripped, 'thumb/', ''), concat('/', str:split($stripped, '/')[last()]), ''))"/>
    <xsl:text>&#10;</xsl:text>
  </xsl:for-each>
  <xsl:for-each select="$title//xhtml:div[@id='bodyContent']/xhtml:div[@class='floatleft' and contains(., xhtml:img)]">
    <xsl:variable name="src" select=".//xhtml:img/@src"/>
    <xsl:variable name="stripped" select="str:replace($src, concat('/', str:split($src, '/')[1], '/'), '')"/>
    <xsl:value-of select="concat($base, $stripped)"/>
    <xsl:text>&#10;</xsl:text>
  </xsl:for-each>
  <xsl:for-each select="$title//xhtml:a[starts-with(@href, 'http')]">
    <xsl:if test="not(ancestor::xhtml:tr[@id='download'])">
      <xsl:if test="contains('exe msi pdf lngx xml oxt xpi', str:split(@href, '.')[last()])">
        <xsl:value-of select="@href"/>
        <xsl:text>&#10;</xsl:text>
      </xsl:if>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<!-- Mandatory identity template -->
<xsl:template match="@*|node()">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()"/>
  </xsl:copy>
</xsl:template>

<!-- Clean up transformation remnants -->
<xsl:template match="@version"/>
<xsl:template match="@xml:space"/>

<!-- Define technical details for the output -->
<xsl:output method="xml" version="1.0"
            mediatype="text/xhtml" encoding="UTF-8" indent="yes"
            doctype-public="-//W3C//DTD XHTML 1.1//EN"
            doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"/>

</xsl:stylesheet>
