# encoding: utf-8
# invoke as:
# /www/valo-cd/htdocs$ python scripts/luo-ohjelmat-html.py
#
# TODO: input and output is hard coded here, should be parameters?

from lxml import etree

ns = {'xhtml': 'http://www.w3.org/1999/xhtml'}

def introElement(item):
    if item['replaces']:
        item['replaces_text'] = "<br /><em>Vaihtoehto ohjelmalle " + item['replaces'] + "</em><br />"
    else:
        item['replaces_text'] = ""
    return """
<tr>
  <td>
    <img alt="%(name)s" src="%(iconurl)s" width="128" height="128" />
  </td>
  <td>
    <a href="%(titlelink)s">
      <h4>%(name)s</h4>
    </a>
    %(description)s
    %(replaces_text)s
  </td>
</tr>
""" % item

def introDocElement(item):
    return """
<tr>
  <td colspan="2">
    <a href="%(titlelink)s">
      <h4>%(name)s</h4>
    </a>
    %(intro)s
  </td>
</tr>
""" % item

# Output name must not infere with html/php page namespaces
# dont use ohjelmat.something or programs.something
output = file("ohjelmat-v9.html", "w")

tree = etree.parse("http://www.valo-cd.fi/wiki/Versio_9")

sections = tree.xpath("//xhtml:h2", namespaces=ns)

for section in sections:
    sectionname = section.xpath("string()").strip()
    print " * "+sectionname
    if sectionname == u"Lisätietoja":
        continue
    output.write(("""
<tr>
  <td colspan="2">
    <h3>%s</h3>
  </td>
</tr>
""" % (sectionname,)).encode("utf-8"))

    titles = section.xpath("following-sibling::xhtml:ul[1]/xhtml:li/xhtml:a", namespaces=ns)
    for title in titles:
        wikiurl = title.xpath("@href")[0]
        titleurl = "http://valo-cd.fi" + wikiurl
        titlename = title.xpath("string()").strip()
        print "   * "+titlename, titleurl

        titletree = etree.parse(titleurl)

        def extract(xpath):
            return titletree.xpath(xpath, namespaces=ns)        

        def extract_first(xpath):
            res = extract(xpath)
            if not res:
                return None
            return res[0]

        def extract_string(xpath):
            res = extract(xpath)
            if not res:
                return None
            return res[0].xpath("string()").strip()

        item = dict(name=titlename,
                    wikiurl=wikiurl,
                    titleurl=titleurl,
                    iconurl=extract_first("//xhtml:tr[@id='icon']//xhtml:img/@src"),
                    downloadurl=extract_first("//xhtml:tr[@id='download']//xhtml:a/@href"),
                    version=extract_string("//xhtml:tr[@id='version']/xhtml:td"),
                    description=extract_first("//xhtml:tr[@id='icon']//xhtml:a/@title"),
                    intro=etree.tostring(extract_first("//xhtml:div[@id='bodyContent']/xhtml:p"), encoding="utf-8").decode("utf-8"),
                    replaces=extract_string("//xhtml:tr[@id='replaces']/xhtml:td"),
                    )

        filename = item['downloadurl']

        if not filename:
            continue

        if filename.endswith(".exe") or filename.endswith(".msi"):
            title_link = "ilmainen_"+filename.split("/")[-1].split("-")[0]
        else:
            title_link = "ilmainen_"+filename.split("/")[-1].split(".")[0]
        item['titlelink'] = title_link

        if item['iconurl']:
            output.write(introElement(item).encode("utf-8"))
        else:
            output.write(introDocElement(item).encode("utf-8"))
        
